cross-ws is a web and native stream based WebSocket client.
Structs
- WebSocket
Receiver - Stream-based WebSocket receiver.
- WebSocket
Sender - Stream-based WebSocket sender.
- WebSocket
With Backend - Stream-based WebSocket.
Enums
- Error
- All possible errors emitted by the WebSocket.
- Message
- An enum representing the various forms of a WebSocket message.
Type Aliases
- Backend
Error - Specific error to each backend.
- Result
- Result type of cross-ws.
- WebSocket
- Type alias for WebSocket with the default backend.