Crate cross_ws

Crate cross_ws 

nash-ws is a web and native stream based WebSocket client.

Structs

WebSocket
Stream-based WebSocket.
WebSocketReceiver
Stream-based WebSocket receiver.
WebSocketSender
WebSocket sender. Also responsible for closing the connection.

Enums

Error
All possible errors emitted by the WebSocket.
Message
An enum representing the various forms of a WebSocket message.

Type Aliases

BackendError
Specific error to each backend. Backend error type.
WebsocketResult
Result type of nash-ws.