nash-ws is a web and native stream based WebSocket client.
Structs
- WebSocket
- Stream-based WebSocket.
- WebSocket
Receiver - Stream-based WebSocket receiver.
- WebSocket
Sender - WebSocket sender. Also responsible for closing the connection.
Enums
- Error
- All possible errors emitted by the WebSocket.
- Message
- An enum representing the various forms of a WebSocket message.
Type Aliases
- Backend
Error - Specific error to each backend. Backend error type.
- Websocket
Result - Result type of nash-ws.