Message

Enum Message 

pub enum Message {
    Text(String),
    Binary(Vec<u8>),
    Close(Option<String>),
}
An enum representing the various forms of a WebSocket message.

Variants



Text(String)

A text WebSocket message.



Binary(Vec<u8>)

A binary WebSocket message.



Close(Option<String>)

Message sent when the connection is closed.

Implementations

Source

impl Message

pub fn is_text(&self) -> bool

Returns true if this is a Message::Text, otherwise false

pub fn as_text_mut(&mut self) -> Option<&mut String>

Optionally returns mutable references to the inner fields if this is a Message::Text, otherwise None

pub fn as_text(&self) -> Option<&String>

Optionally returns references to the inner fields if this is a Message::Text, otherwise None

pub fn into_text(self) -> Result<String, Self>

Returns the inner fields if this is a Message::Text, otherwise returns back the enum in the Err case of the result

pub fn is_binary(&self) -> bool

Returns true if this is a Message::Binary, otherwise false

pub fn as_binary_mut(&mut self) -> Option<&mut Vec<u8>>

Optionally returns mutable references to the inner fields if this is a Message::Binary, otherwise None

pub fn as_binary(&self) -> Option<&Vec<u8>>

Optionally returns references to the inner fields if this is a Message::Binary, otherwise None

pub fn into_binary(self) -> Result<Vec<u8>, Self>

Returns the inner fields if this is a Message::Binary, otherwise returns back the enum in the Err case of the result

pub fn is_close(&self) -> bool

Returns true if this is a Message::Close, otherwise false

pub fn as_close_mut(&mut self) -> Option<&mut Option<String>>

Optionally returns mutable references to the inner fields if this is a Message::Close, otherwise None

pub fn as_close(&self) -> Option<&Option<String>>

Optionally returns references to the inner fields if this is a Message::Close, otherwise None

pub fn into_close(self) -> Result<Option<String>, Self>

Returns the inner fields if this is a Message::Close, otherwise returns back the enum in the Err case of the result